synapse.app.homeserver module — Synapse 1.0 documentation

# synapse.app.homeserver module

class `synapse.app.homeserver.` `SynapseHomeServer`(hostname, reactor=None, **kwargs)

  Bases: `synapse.server.HomeServer`

  `DATASTORE_CLASS`

    alias of `synapse.storage.DataStore`

  `run_startup_checks`(db_conn, database_engine)
  `start_listening`()

class `synapse.app.homeserver.` `SynapseService`(config)

  Bases: `twisted.application.service.Service`

  A twisted Service class that will start synapse. Used to run synapse via twistd and a .tac.

  `startService`()
  `stopService`()

`synapse.app.homeserver.` `gz_wrap`(r)

`synapse.app.homeserver.` `main`()

`synapse.app.homeserver.` `run`(hs)

`synapse.app.homeserver.` `setup`(config_options)

  Parameters: | config_options_options – The options passed to Synapse. Usually sys.argv[1:].
  Returns: | HomeServer